import fs from'fs';
import{execSync}from'child_process';
var stylezero_style_version=1;
var allow_stylezero_execution=true;
const stylezero_bin=process.platform==='win32'?'%LocalAppData%\\Programs\\StyleZero\\stylezero':'~/.local/opt/stylezero/stylezero';
var __dir__=process.cwd().replaceAll('\\','/');
export default function stylezero(){
	return{
		name:'stylezero',
		enforce:'pre',
		transform(code,path){
			if(SETUP_CHECK_FILE_EXTENSIONS)
				return;
			if(allow_stylezero_execution){
				allow_stylezero_execution=false;
				setTimeout(()=>allow_stylezero_execution=true,1000);
				execSync(stylezero_bin,{encoding:'utf-8'});
			}
			var compiled_path=path.replace(__dir__+'/src/',__dir__+'/SETUP_PLUGIN_DIR/cache/');
			return fs.readFileSync(compiled_path,'utf-8');
		}
	}
};
